@@ -1,4 +1,3 @@
-
 /*
  * Portions of this file are copied or derivered from various files in the
  * tcl8.0b1 distribution. 
@@ -17,10 +16,14 @@
 #include <stdio.h>
 #include <errno.h>
 #include <tcl.h>
-#include <pi-source.h>
-#include <pi-socket.h>
-#include <pi-dlp.h>
-#include <pi-memo.h>
+
+#include "pi-source.h"
+#include "pi-socket.h"
+#include "pi-dlp.h"
+#include "pi-memo.h"
+#include "pi-buffer.h"
+#include "pi-userland.h"
+
 
 #if TCL_MAJOR_VERSION >= 8
 # define Objects
@@ -138,8 +141,12 @@ struct Packer {
 void MemoUnpackCmd(Tcl_Interp * interp, char * buf, int len)
 {
 	struct Memo m;
-	
-	len = unpack_Memo(&m, buf, len);
+	pi_buffer_t *record;
+	record = pi_buffer_new(len);
+	memcpy(record->data, buf, len);
+	record->used = len;
+	len = unpack_Memo(&m, record, len);
+	pi_buffer_free(record);
 
 	Tcl_AppendElement(interp, m.text);
 	free_Memo(&m);
@@ -149,10 +156,22 @@ void MemoUnpackCmd(Tcl_Interp * interp, char * buf, int len)
 int MemoPackCmd(Tcl_Interp * interp, char * rec, char * buf, int len)
 {
 	struct Memo m;
-	
+	pi_buffer_t *record;
+	int used;
+	record = pi_buffer_new(0);	
+
 	m.text = rec;
 	
-	return pack_Memo(&m, buf, len);
+	pack_Memo(&m, record, memo_v1);
+	if (record->used <= len) {
+	  memcpy(buf,record->data,record->used);
+	  used = record->used;
+	} else {
+	  /* It didn't fit in their fixed size buffer */
+	  used = 0;
+	}
+	pi_buffer_free(record);
+	return used;
 }
 
 struct { char * name; packcmd pack, packai, packsi; unpackcmd unpack, unpackai, unpacksi; }
@@ -691,12 +710,8 @@ CreateSocket(Tcl_Interp * interp, int protocol, char * remote, int server)
 	}
 	printf("addr = %ld\n", (long)addr);
 
-	if (server) {
-		result = pi_bind(sock, (struct sockaddr*)addr, alen);
-		pi_listen(sock, 1);
-	} else {
-      result = pi_connect(sock, (struct sockaddr*)addr, alen);
-	}
+	result = plu_connect();
+	pi_listen(sock, 1);
 	printf(" result = %d\n", result);
 
    return statePtr;
@@ -967,7 +982,7 @@ bindCmd(ClientData clientData, Tcl_Interp * interp, int argc, char * argv[])
 		addr->pi_family = family;
 	}
 	
-	result = pi_bind(s, (struct sockaddr*)addr, alen);
+	result = plu_connect();
 	
 	if (addr)
 		free(addr);
@@ -1090,7 +1105,7 @@ GetRecordCmd(ClientData clientData, Tcl_Interp * interp, int argc, char *argv[])
 	int index;
 	int sock;
 	int len,attr,cat;
-	recordid_t id;
+	recordid_t id_;
 	
 	if (argc != 4 ) {
 		Tcl_SetResult(interp, "Usage: GetRecord socket dbhandle index", TCL_STATIC);
@@ -1108,7 +1123,7 @@ GetRecordCmd(ClientData clientData, Tcl_Interp * interp, int argc, char *argv[])
 		return TCL_ERROR;
 	}
 	
-	result = dlp_ReadRecordByIndex(tcl_socket(interp, argv[1]), handle, index, buf, &id, &len, &attr, &cat);
+	result = dlp_ReadRecordByIndex(tcl_socket(interp, argv[1]), handle, index, buf, &id_, &attr, &cat);
 	
 	if (result<0) {
 		Tcl_SetResult(interp, dlp_strerror(result), TCL_STATIC);
@@ -1117,7 +1132,7 @@ GetRecordCmd(ClientData clientData, Tcl_Interp * interp, int argc, char *argv[])
 	
 	pack[sock].unpack(interp, buf, len);
 	Tcl_AppendInt(interp, index);
-	Tcl_AppendInt(interp, id);
+	Tcl_AppendInt(interp, id_);
 	Tcl_AppendInt(interp, attr);
 	Tcl_AppendInt(interp, cat);
 
@@ -1132,7 +1147,7 @@ SetRecordCmd(ClientData clientData, Tcl_Interp * interp, int argc, char *argv[])
 	int index;
 	int sock;
 	int len,attr,cat;
-	recordid_t id;
+	recordid_t id_;
 	
 	if (argc != 7 ) {
 		Tcl_SetResult(interp, "Usage: SetRecord socket dbhandle record id attr cat", TCL_STATIC);
@@ -1149,13 +1164,13 @@ SetRecordCmd(ClientData clientData, Tcl_Interp * interp, int argc, char *argv[])
 		return TCL_ERROR;
 	}
 	
-	Tcl_GetInt(interp, argv[4], &index); id = index;
+	Tcl_GetInt(interp, argv[4], &index); id_ = index;
 	Tcl_GetInt(interp, argv[5], &attr);
 	Tcl_GetInt(interp, argv[6], &cat);
 
 	len = pack[sock].pack(interp, argv[3], buf, 0xffff);
 	
-	result = dlp_WriteRecord(sock, handle, attr, id, cat, buf, len, &id);
+	result = dlp_WriteRecord(sock, handle, attr, id_, cat, buf, len, &id_);
 	
 	free(buf);
 	
@@ -1164,7 +1179,7 @@ SetRecordCmd(ClientData clientData, Tcl_Interp * interp, int argc, char *argv[])
 		return TCL_ERROR;
 	}
 	
-	Tcl_AppendInt(interp, (int)id);
+	Tcl_AppendInt(interp, (int)id_);
 
 	return TCL_OK;
 }
