@@ -1,7 +1,8 @@
 /*
- * address.c:  Translate Pilot address book data formats
+ * $Id: address.c,v 1.30 2006/11/22 22:52:25 adridg Exp $
  *
- * Copyright (c) 1996, Kenneth Albanowski
+ * address.c:  Translate Pilot address book data formats
+ * (c) 1996, Kenneth Albanowski
  *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Library General Public License as published by
@@ -68,7 +69,7 @@ free_Address(Address_t *addr)
  *
  ***********************************************************************/
 int
-unpack_Address(Address_t *addr, pi_buffer_t *buf, addressType type)
+unpack_Address(Address_t *addr, const pi_buffer_t *buf, addressType type)
 {
 	unsigned long	contents,
 			v;
@@ -130,7 +131,7 @@ unpack_Address(Address_t *addr, pi_buffer_t *buf, addressType type)
  *
  ***********************************************************************/
 int
-pack_Address(Address_t *addr, pi_buffer_t *buf, addressType type)
+pack_Address(const Address_t *addr, pi_buffer_t *buf, addressType type)
 {
 	unsigned int	l,
 			destlen = 9;
@@ -203,7 +204,7 @@ pack_Address(Address_t *addr, pi_buffer_t *buf, addressType type)
  *
  ***********************************************************************/
 int
-unpack_AddressAppInfo(AddressAppInfo_t *ai, unsigned char *record, size_t len)
+unpack_AddressAppInfo(AddressAppInfo_t *ai, const unsigned char *record, size_t len)
 {
 	size_t 	i,
 		destlen = 4 + 16 * 22 + 2 + 2;
@@ -259,7 +260,7 @@ unpack_AddressAppInfo(AddressAppInfo_t *ai, unsigned char *record, size_t len)
  *
  ***********************************************************************/
 int
-pack_AddressAppInfo(AddressAppInfo_t *ai, unsigned char *record, size_t len)
+pack_AddressAppInfo(const AddressAppInfo_t *ai, unsigned char *record, size_t len)
 {
 	int 	i;
 	size_t	destlen = 4 + 16 * 22 + 2 + 2;
@@ -303,3 +304,10 @@ pack_AddressAppInfo(AddressAppInfo_t *ai, unsigned char *record, size_t len)
 
 	return (pos - record);
 }
+
+/* vi: set ts=8 sw=4 sts=4 noexpandtab: cin */
+/* ex: set tabstop=4 expandtab: */
+/* Local Variables: */
+/* indent-tabs-mode: t */
+/* c-basic-offset: 8 */
+/* End: */
