@@ -1,5 +1,5 @@
 /*
- * $Id: pilot-csd.c,v 1.1.1.2 2007-02-14 21:21:15 rousseau Exp $ 
+ * $Id: pilot-csd.c,v 1.44 2009/06/04 13:32:31 desrod Exp $ 
  *
  * pilot-csd.c: Connection Service Daemon, required for accepting logons via
  *           NetSync(tm)
@@ -48,7 +48,8 @@
 #include "pi-userland.h"
 #include "pi-debug.h"
 
-char hostname[130];
+static char hostname_[130];		/* buffer fetch_host() can write to. */
+static char *hostname = hostname_;	/* pointer poptGetNextOpt() can change. */
 struct in_addr address, netmask;
 
 #ifdef HAVE_SA_LEN
