@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  *
  *
  * This regression test calls every DLP function except the following:
@@ -24,12 +24,9 @@
  *    dlp_ProcessRPC
  */
 
-#include <stdlib.h>
 #include <stdio.h>
-#include <string.h>
-#include "pi-macros.h"
+
 #include "pi-debug.h"
-#include "pi-socket.h"
 #include "pi-source.h"
 #include "pi-dlp.h"
 
@@ -64,20 +61,31 @@ main (int argc, char **argv)
 	struct NetSyncInfo n1, n2;
 	struct CardInfo c;
 	struct DBInfo dbi;
+	struct DBSizeInfo dbsi;
 	unsigned long romVersion;
 	time_t t1, t2;	
 	int handle;
 	unsigned char pref1[256], pref2[256];
-	unsigned char ablock1[256], ablock2[256];
-	unsigned char sblock1[256], sblock2[256];
-	unsigned char ires1[256], ires2[256];
-	unsigned char dres1[256], dres2[256];
-	unsigned char record1[256], record2[256], record3[256], record4[256];
+	unsigned char ablock1[256];
+	unsigned char sblock1[256];
+	unsigned char ires1[256];
+	unsigned char dres1[256];
+	unsigned char record1[256], record2[256], record3[256];
 	recordid_t rid1, rid2, rid3, rlist[4];
-	int index, id, count;
+	int index, id_, count;
 	unsigned long type;
+	int cardno;
 	int i;
+	pi_buffer_t *record4,
+		*dres2,
+		*ires2,
+		*appblock;
 
+	record4 = pi_buffer_new (sizeof(record1));
+	ires2 = pi_buffer_new (sizeof (ires1));
+	dres2 = pi_buffer_new (sizeof (dres1));
+	appblock = pi_buffer_new(256);
+	
 	sd = pilot_connect (argv[1]);
 
 	t1 = time (NULL);
@@ -246,8 +254,9 @@ main (int argc, char **argv)
 	 *********************************************************************/
 	dbi.more = 1;
 	for (i = 0; dbi.more != 0; i++) {
-		result = dlp_ReadDBList (sd, 0, dlpDBListRAM | dlpDBListROM, i, &dbi);
+		result = dlp_ReadDBList (sd, 0, dlpDBListRAM | dlpDBListROM, i, record4);
 		CHECK_RESULT(dlp_ReadDBList);
+		memcpy(&dbi, record4->data, sizeof(struct DBInfo));
 	}
 
 	/*********************************************************************
@@ -287,6 +296,63 @@ main (int argc, char **argv)
 	result = dlp_DeleteDB (sd, 0, "TestResource");
 	CHECK_RESULT(dlp_DeleteDB);
 
+	/*********************************************************************
+	 *
+	 * Test: Database Info and Searching
+	 *
+	 * Direct Testing Functions:
+	 *   dlp_SetDBInfo
+	 *   dlp_FindDBByName
+	 *   dlp_FindDBByOpenHandle
+	 *   dlp_FindDBByTypeCreator
+	 *
+	 * Indirect Testing Functions:
+	 *   dlp_CreateDB
+	 *   dlp_OpenDB
+	 *   dlp_ReadDBList
+	 *   dlp_CloseDB
+	 *   dlp_DeleteDB
+	 *
+	 *********************************************************************/
+#if DLP_1_2
+	result = dlp_CreateDB (sd, CREATOR, DATA, 0, 0, 1, "TestRecord", &handle);
+	CHECK_RESULT(dlp_CreateDB);
+	result = dlp_SetDBInfo (sd, handle, dlpDBFlagBackup, dlpDBFlagCopyPrevention, 0, 0, 0, 0, 0, 0);
+	CHECK_RESULT(dlp_SetDBInfo);	
+	result = dlp_CloseDB (sd, handle);
+	CHECK_RESULT(dlp_CloseDB);
+
+	result = dlp_OpenDB (sd, 0, dlpOpenReadWrite, "TestRecord", &handle);
+	CHECK_RESULT(dlp_OpenDB);
+	
+	result = dlp_FindDBByOpenHandle (sd, handle, &cardno, NULL, &dbi, &dbsi);
+	CHECK_RESULT(dlp_FindDBByOpenHandle);
+	if (strcmp (dbi.name, "TestRecord") || !(dbi.flags & dlpDBFlagBackup)) {
+		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Database info mismatch with openhandle\n"));
+		goto error;
+	}
+
+	result = dlp_CloseDB (sd, handle);
+	CHECK_RESULT(dlp_CloseDB);
+	
+	result = dlp_FindDBByName (sd, 0, "TestRecord", NULL, NULL, &dbi, &dbsi);
+	CHECK_RESULT(dlp_FindDBByName);
+	if (strcmp (dbi.name, "TestRecord") || !(dbi.flags & dlpDBFlagBackup)) {
+		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Database info mismatch with name\n"));
+		goto error;
+	}
+
+	result = dlp_FindDBByTypeCreator (sd, DATA, CREATOR, 1, 0, &cardno, NULL, NULL, &dbi, &dbsi);
+	CHECK_RESULT(dlp_FindDBByName);
+	if (strcmp (dbi.name, "TestRecord") || !(dbi.flags & dlpDBFlagBackup)) {
+		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Database info mismatch with type/creator\n"));
+		goto error;
+	}
+
+	result = dlp_DeleteDB (sd, 0, "TestRecord");
+	CHECK_RESULT(dlp_DeleteDB);
+#endif
+
 	/*********************************************************************
 	 *
 	 * Test: App Preference
@@ -341,9 +407,7 @@ main (int argc, char **argv)
 	 *
 	 *********************************************************************/
 	memset (ablock1, '\0', sizeof (ablock1));
-	memset (ablock2, '\0', sizeof (ablock2));
 	memset (sblock1, '\0', sizeof (sblock1));
-	memset (sblock2, '\0', sizeof (sblock2));
 	memset (record1, '\0', sizeof (record1));
 	memset (record2, '\0', sizeof (record2));
 	memset (record3, '\0', sizeof (record3));
@@ -359,9 +423,9 @@ main (int argc, char **argv)
 	/* Write and read back an app block */
 	result = dlp_WriteAppBlock (sd, handle, ablock1, sizeof(ablock1));
 	CHECK_RESULT(dlp_WriteAppBlock);
-	result = dlp_ReadAppBlock (sd, handle, 0, ablock2, sizeof(ablock2));
+	result = dlp_ReadAppBlock (sd, handle, 0, sizeof(ablock1), appblock);
 	CHECK_RESULT(dlp_ReadAppBlock);
-	if (memcmp(ablock1, ablock2, sizeof(ablock1) != 0)) {
+	if (result != sizeof(ablock1) || memcmp(ablock1, appblock->data, sizeof(ablock1) != 0)) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST App block mismatch\n"));
 		goto error;
 	}
@@ -369,9 +433,9 @@ main (int argc, char **argv)
 	/* Write and read back a sort block */
 	result = dlp_WriteSortBlock (sd, handle, sblock1, sizeof(sblock1));
 	CHECK_RESULT(dlp_WriteSortBlock);
-	result = dlp_ReadSortBlock (sd, handle, 0, sblock2, sizeof(sblock2));
+	result = dlp_ReadSortBlock (sd, handle, 0, sizeof(sblock1), appblock);
 	CHECK_RESULT(dlp_ReadSortBlock);
-	if (memcmp(sblock1, sblock2, sizeof(sblock1) != 0)) {
+	if (result != sizeof(sblock1) || memcmp(sblock1, appblock->data, sizeof(sblock1) != 0)) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST App block mismatch\n"));
 		goto error;
 	}
@@ -407,21 +471,21 @@ main (int argc, char **argv)
 	}
 	
 	/* Try reading the records in various ways */
-	result = dlp_ReadRecordById (sd, handle, rid1, record4, &index, NULL, NULL, NULL);
+	result = dlp_ReadRecordById (sd, handle, rid1, record4, &index, NULL, NULL);
 	CHECK_RESULT(dlp_ReadRecordById);
-	if (memcmp(record1, record4, sizeof(record1) != 0)) {
+	if (memcmp(record1, record4->data, sizeof(record1) != 0)) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Record by Id mismatch\n"));
 		goto error;
 	}
-	result = dlp_ReadRecordByIndex (sd, handle, index, record4, NULL, NULL, NULL, NULL);
+	result = dlp_ReadRecordByIndex (sd, handle, index, record4, NULL, NULL, NULL);
 	CHECK_RESULT(dlp_ReadRecordByIndex);
-	if (memcmp(record1, record4, sizeof(record1) != 0)) {
+	if (memcmp(record1, record4->data, sizeof(record1) != 0)) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Record by index mismatch\n"));
 		goto error;
 	}
-	result = dlp_ReadNextModifiedRec (sd, handle, record4, NULL, NULL, NULL, NULL, NULL);
+	result = dlp_ReadNextModifiedRec (sd, handle, record4, NULL, NULL, NULL, NULL);
 	CHECK_RESULT(dlp_ReadNextModifiedRec);
-	if (memcmp(record2, record4, sizeof(record2) != 0)) {
+	if (memcmp(record2, record4->data, sizeof(record2) != 0)) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Next modified record mismatch\n"));
 		goto error;
 	}
@@ -431,9 +495,9 @@ main (int argc, char **argv)
 	CHECK_RESULT(dlp_ResetDBIndex)
 
 	/* This is a DLP 1.1 call, but pilot-link has a 1.0 implementation */
-	result = dlp_ReadNextRecInCategory (sd, handle, 3, record4, NULL, NULL, NULL, NULL);
+	result = dlp_ReadNextRecInCategory (sd, handle, 3, record4, NULL, NULL, NULL);
 	CHECK_RESULT(dlp_ReadNextRecInCategory)
-	if (memcmp(record3, record4, sizeof(record3) != 0)) {
+	if (memcmp(record3, record4->data, sizeof(record3) != 0)) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST dlp_ReadNextRecInCategory mismatch\n"));
 		goto error;
 	}
@@ -443,9 +507,9 @@ main (int argc, char **argv)
 	CHECK_RESULT(dlp_ResetDBIndex)
 
 	/* This is a DLP 1.1 call, but pilot-link has a 1.0 implementation */
-	result = dlp_ReadNextModifiedRecInCategory (sd, handle, 2, record4, NULL, NULL, NULL, NULL);
+	result = dlp_ReadNextModifiedRecInCategory (sd, handle, 2, record4, NULL, NULL, NULL);
 	CHECK_RESULT(dlp_ReadNextModifiedRecInCategory)
-	if (memcmp(record2, record4, sizeof(record2) != 0)) {
+	if (memcmp(record2, record4->data, sizeof(record2) != 0)) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST dlp_ReadNextModifiedRecInCategory mismatch\n"));
 		goto error;
 	}
@@ -457,9 +521,9 @@ main (int argc, char **argv)
 	/* Move a category and try to read the record back in */
 	result = dlp_MoveCategory (sd, handle, 1, 4);
 	CHECK_RESULT(dlp_MoveCategory)
-	result = dlp_ReadNextRecInCategory (sd, handle, 4, record4, NULL, NULL, NULL, NULL);
+	result = dlp_ReadNextRecInCategory (sd, handle, 4, record4, NULL, NULL, NULL);
 	CHECK_RESULT(dlp_ReadNextRecInCategory)
-	if (memcmp(record1, record4, sizeof(record1) != 0)) {
+	if (memcmp(record1, record4->data, sizeof(record1) != 0)) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST dlp_ReadNextRecInCategory mismatch\n"));
 		goto error;
 	}
@@ -467,21 +531,21 @@ main (int argc, char **argv)
 	/* Delete records in various ways */
 	result = dlp_DeleteRecord (sd, handle, 0, rid1);
 	CHECK_RESULT(dlp_DeleteRecord <Single>);
-	result = dlp_ReadRecordById (sd, handle, rid1, record4, NULL, NULL, NULL, NULL);
+	result = dlp_ReadRecordById (sd, handle, rid1, record4, NULL, NULL, NULL);
 	if (result >= 0) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Deleted record could still be read\n"));
 		goto error;
 	}
 	result = dlp_DeleteCategory (sd, handle, 3);
 	CHECK_RESULT(dlp_DeleteCategory);
-	result = dlp_ReadRecordById (sd, handle, rid3, record4, NULL, NULL, NULL, NULL);
+	result = dlp_ReadRecordById (sd, handle, rid3, record4, NULL, NULL, NULL);
 	if (result >= 0) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Deleted category could still be read\n"));
 		goto error;
 	}
 	result = dlp_DeleteRecord (sd, handle, 1, 0);
 	CHECK_RESULT(dlp_DeleteRecord <All>);
-	result = dlp_ReadRecordById (sd, handle, rid2, record4, NULL, NULL, NULL, NULL);
+	result = dlp_ReadRecordById (sd, handle, rid2, record4, NULL, NULL, NULL);
 	if (result >= 0) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Deleted all record could still be read\n"));
 		goto error;
@@ -509,9 +573,7 @@ main (int argc, char **argv)
 	 *
 	 *********************************************************************/
 	memset (ires1, '\0', sizeof (ires1));
-	memset (ires2, '\0', sizeof (ires2));
 	memset (dres1, '\0', sizeof (dres1));
-	memset (dres2, '\0', sizeof (dres2));
 	ires1[3] = 'T';
 	dres1[4] = 'T';
 
@@ -525,15 +587,15 @@ main (int argc, char **argv)
 	CHECK_RESULT(dlp_WriteResource);
 
 	/* Read in the resources by various methods */
-	result = dlp_ReadResourceByType (sd, handle, INFO, 1, ires2, &index, NULL);
+	result = dlp_ReadResourceByType (sd, handle, INFO, 1, ires2, &index);
 	CHECK_RESULT(dlp_ReadResourceByType)
-	if (memcmp(ires1, ires2, sizeof(ires1) != 0)) {
+	if (memcmp(ires1, ires2->data, sizeof(ires1) != 0)) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Resource by type mismatch\n"));
 		goto error;
 	}
-	result = dlp_ReadResourceByIndex (sd, handle, index, ires2, &type, &id, NULL);
+	result = dlp_ReadResourceByIndex (sd, handle, index, ires2, &type, &id_);
 	CHECK_RESULT(dlp_ReadResourceByIndex)
-	if (memcmp(ires1, ires2, sizeof(ires1) != 0)) {
+	if (memcmp(ires1, ires2->data, sizeof(ires1) != 0)) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Resource by index mismatch\n"));
 		goto error;
 	}
@@ -541,7 +603,7 @@ main (int argc, char **argv)
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Resource by index return type mismatch\n"));
 		goto error;
 	}
-	if (id != 1) {
+	if (id_ != 1) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Resource by index return id mismatch\n"));
 		goto error;
 	}
@@ -549,14 +611,14 @@ main (int argc, char **argv)
 	/* Delete resources by the various methods */
 	result = dlp_DeleteResource (sd, handle, 0, INFO, 1);
 	CHECK_RESULT(dlp_DeleteResource <Single>)
-	result = dlp_ReadResourceByType (sd, handle, INFO, 1, ires2, &index, NULL);
+	result = dlp_ReadResourceByType (sd, handle, INFO, 1, ires2, &index);
 	if (result >= 0) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Deleted resource could still be read\n"));
 		goto error;
 	}
 	result = dlp_DeleteResource (sd, handle, 1, INFO, 1);
 	CHECK_RESULT(dlp_DeleteResource <All>)
-	result = dlp_ReadResourceByType (sd, handle, DATA, 0, dres2, &index, NULL);
+	result = dlp_ReadResourceByType (sd, handle, DATA, 0, dres2, &index);
 	if (result >= 0) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Deleted all resource could still be read\n"));
 		goto error;
@@ -604,12 +666,12 @@ main (int argc, char **argv)
 	result = dlp_OpenDB (sd, 0, dlpOpenReadWrite, "TestRecord", &handle);
 	CHECK_RESULT(dlp_OpenDB);
 
-	result = dlp_ReadRecordById (sd, handle, rid1, record4, NULL, NULL, NULL, NULL);
+	result = dlp_ReadRecordById (sd, handle, rid1, record4, NULL, NULL, NULL);
 	if (result >= 0) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Cleaned up record could still be read\n"));
 		goto error;
 	}
-	result = dlp_ReadNextModifiedRec (sd, handle, record4, NULL, NULL, NULL, NULL, NULL);
+	result = dlp_ReadNextModifiedRec (sd, handle, record4, NULL, NULL, NULL, NULL);
 	if (result >= 0) {
 		LOG((PI_DBG_USER, PI_DBG_LVL_ERR, "DLPTEST Modified recorded could still be read\n"));
 		goto error;
@@ -653,7 +715,10 @@ main (int argc, char **argv)
 
  error:
 	pi_close (sd);
-
+	pi_buffer_free (record4);
+	pi_buffer_free (ires2);
+	pi_buffer_free (dres2);
+	pi_buffer_free(appblock);
 	return 0;
 }
 
